/**
 * @package css-modules-types-loader
 * @license MIT
 * @version 0.5.13
 * @author nuintun <nuintun@qq.com>
 * @description A webpack loader that dynamically generates TypeScript typings for CSS modules from css-loader.
 * @see https://github.com/nuintun/css-modules-types-loader#readme
 */

import { writeFile } from 'fs/promises';
import { generateTypings, removeFile } from './utils.js';

/**
 * @module generate
 */
async function generate({ eol, path, banner, content }) {
  const typings = generateTypings(content, banner, eol);
  if (typings) {
    await writeFile(path, typings);
    return { path, action: 'generate' /* Action.GENERATE */ };
  }
  await removeFile(path);
  return { path, action: 'remove' /* Action.REMOVE */ };
}

export { generate as default };
